@@ -1,7 +1,7 @@
-from ppi_client.api.constants import ACCOUNT_LOGIN, ACCOUNT_REFRESH_TOKEN, ACCOUNT_ACCOUNTS, ACCOUNT_BANK_ACCOUNTS, \
+from ppi_client.api.constants import ACCOUNT_REFRESH_TOKEN, ACCOUNT_ACCOUNTS, ACCOUNT_BANK_ACCOUNTS, \
     ACCOUNT_AVAILABLE_BALANCE, ACCOUNT_BALANCE_POSITIONS, ACCOUNT_MOVEMENTS, ACCOUNT_INVESTING_PROFILE_QUESTIONS, \
     ACCOUNT_INVESTING_PROFILE_INSTRUMENT_TYPES, ACCOUNT_INVESTING_PROFILE, ACCOUNT_SET_INVESTING_PROFILE, \
-    ACCOUNT_REGISTER_BANK_ACCOUNT, ACCOUNT_REGISTER_FOREIGN_BANK_ACCOUNT, ACCOUNT_CANCEL_BANK_ACCOUNT
+    ACCOUNT_REGISTER_BANK_ACCOUNT, ACCOUNT_REGISTER_FOREIGN_BANK_ACCOUNT, ACCOUNT_CANCEL_BANK_ACCOUNT, ACCOUNT_LOGIN_API
 from ppi_client.ppi_api_client import PPIClient
 from ppi_client.models.account_movements import AccountMovements
 from ppi_client.models.investing_profile import InvestingProfile
@@ -17,25 +17,22 @@ class AccountsApi(object):
     def __init__(self, api_client):
         self.__api_client = api_client
 
-    def login(self, client_id: str, client_secret: str):
-        """Tries to log in with the given credentials. Returns a session token which is needed to use the API.
+    def login_api(self, api_key: str, api_secret: str):
+        """Tries to log in with the given api credentials. Returns a session token which is needed to use the API.
 
-        :param client_id: Client id
-        :type client_id: str
-        :param client_secret: Client secret
-        :type client_secret: str
+        :param api_key: api key
+        :type api_secret: str
+        :param api_secret: api secret
+        :type api_secret: str
         :rtype: authorization payload, including access_token, refresh_token and expiration date.
         """
-        login = {
-            "user": client_id,
-            "password": client_secret
-        }
-        res = self.__api_client.post(ACCOUNT_LOGIN, data=login)
+
+        res = self.__api_client.post(ACCOUNT_LOGIN_API, api_key=api_key, api_secret=api_secret)
         self.__api_client.token = res['accessToken']
         self.__api_client.refreshToken = res['refreshToken']
         self.__api_client.refreshedCant = 0
-        self.__api_client.get_rest_client().client_id = client_id
-        self.__api_client.get_rest_client().client_secret = client_secret
+        self.__api_client.get_rest_client().api_key = api_key
+        self.__api_client.get_rest_client().api_secret = api_secret
 
         return res
 
