@@ -1,7 +1,10 @@
+import decimal
+
 from ppi_client.api.constants import MARKETDATA_SEARCH_INSTRUMENT, MARKETDATA_SEARCH, MARKETDATA_CURRENT, \
-    MARKETDATA_BOOK, MARKETDATA_INTRADAY
+    MARKETDATA_BOOK, MARKETDATA_INTRADAY, ESTIMATE_BONDS
 from ppi_client.ppi_api_client import PPIClient
 from datetime import datetime
+from ppi_client.models.estimate_bonds import EstimateBonds
 
 class MarketDataApi(object):
     __api_client: PPIClient
@@ -66,3 +69,22 @@ class MarketDataApi(object):
 
         return self.__api_client.get(MARKETDATA_INTRADAY.format(ticker, instrument_type, settlement))
 
+    def estimate_bonds(self, parameters: EstimateBonds):
+        """Calculate the return on your investments.
+        :type parameters: EstimateBonds
+        :rtype: Calculator information
+        """
+        params = {
+            'ticker': parameters.ticker,
+            'date': parameters.date,
+            'quantityType': parameters.quantityType,
+            'quantity': parameters.quantity,
+            'amountOfMoney': parameters.amountOfMoney,
+            'price': parameters.price,
+            'exchangeRate': parameters.exchangeRate,
+            'equityRate': parameters.equityRate,
+            'exchangeRateAmortization': parameters.exchangeRateAmortization,
+            'rateAdjustmentAmortization': parameters.rateAdjustmentAmortization
+        }
+
+        return self.__api_client.get(ESTIMATE_BONDS.format(), params=params)
\ No newline at end of file
